@@ -194,8 +194,12 @@ class vinex(Exchange):
 
         timestamp = self.milliseconds()
 
+        if not limit:
+            limit = 20
+
         orderbook = self.publicGetGetOrderBook(self.extend({
             'market': self.market_id(symbol),
+            'limit': limit,
         }, params))
 
         return self.parse_order_book(orderbook, timestamp, 'bids', 'asks', 'price', 'quantity')
